Get class final

Annotation for GET endpoints

Constructors

Get({required String path, String? description, int statusCode = 200, bool requiresAuth = false})
const

Properties

description String?
final
hashCode int
The hash code for this object.
no setterinherited
path String
final
requiresAuth bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited