JWTPublic class

Annotation to mark an endpoint as public (without JWT validation)

Overrides any controller or endpoint validation. Has the highest priority in the validation system.

Example:

@GET('/health')
@JWTPublic()
Future<Response> healthCheck(Request request) async {
  // Public endpoint - no JWT validation
}

Constructors

JWTPublic()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited