JWTValidatorBase class abstract

Base abstract class for all custom JWT validators.

Developers extend this class to create specific validators with full control over the JWT structure and validation logic.

Implementers

Constructors

JWTValidatorBase()
Const constructor to allow const validators in annotations
const

Properties

defaultErrorMessage String
Default error message when validation fails
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onValidationFailed(Request request, Map<String, dynamic> jwtPayload, String reason) → void
Optional callback executed when validation fails
onValidationSuccess(Request request, Map<String, dynamic> jwtPayload) → void
Optional callback executed when validation is successful
toString() String
A string representation of this object.
inherited
validate(Request request, Map<String, dynamic> jwtPayload) ValidationResult
Mandatory method that implements the validation logic

Operators

operator ==(Object other) bool
The equality operator.
inherited