PostData class

Specific data for @Post

Inheritance

Constructors

PostData({required String path, String? description, int statusCode = 201, bool requiresAuth = false})
const
PostData.fromMap(Map<String, dynamic> map)
factory

Properties

description String?
final
hashCode int
The hash code for this object.
no setterinherited
path String
final
requiresAuth bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited