QueryParamData class

Specific data for @QueryParam

Inheritance

Constructors

QueryParamData({required String name, bool required = false, dynamic defaultValue, String? description})
const
QueryParamData.fromMap(Map<String, dynamic> map)
factory

Properties

defaultValue → dynamic
final
description String?
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
required bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited