RequestHost class final

Annotation for the request host

Constructors

RequestHost({String? description = 'Request host (e.g., localhost, api.example.com)'})
Gets the request host as a String Example: @RequestHost() String host
const

Properties

description String?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited